
;; SYSTEM ABSOLUTE DEPENDENT PATHS as an alternative to relative paths (TO FIX)
;; (defvar hindi_data_dir1 "/var/source/Hindi")
;;(defvar hindi_data_dir "/var/source/Hindi/db")

;; SYSTEM RELATIVE PATHS (TO FIX)
(defvar  hindi_data_dir1 (path-append libdir "../../hindi/hpl_hindi_multisyn"))
(defvar  hindi_data_dir (path-append libdir "../../hindi/hpl_hindi_multisyn/db"))

; SCHEME PATHS

(defvar multisyn_lib_dir (path-append libdir "multisyn/"))
(defvar uyo_ibibio_eno_multisyn_dir (cdr (assoc 'uyo_ibibio_eno_multisyn voice-locations)))
(if (not (member_string multisyn_lib_dir libdir))
  (set! load-path (cons multisyn_lib_dir load-path)))
(set! load-path (cons (path-append  hindi_data_dir1 "files_scm/")
                      load-path))


;;;  Add the directory contains general voice stuff to load-path
(set! load-path (cons (path-append hindi_data_dir "files_scm/") 
		      load-path))


;; REQUIRES
(require 'multisyn)
(require 'phrase)


;; DATA PATHS

;; Location of Base utterances

(set! hindi_base_dirs (list (path-append hindi_data_dir "utt/")
			   (path-append hindi_data_dir "lpc/")
			   (path-append hindi_data_dir "lpc/")
			   (path-append hindi_data_dir "coef_stripped/")
			   ".utt" ".res" ".lpc" ".coef"))
;; Location of Pauses
;; These are currently silence so we just use the waveforms
(set! hindi_pauses_dirs (list (path-append hindi_data_dir "pauses/utt/")
			     (path-append hindi_data_dir "pauses/wav/")
			     (path-append hindi_data_dir "pauses/pm/")
			     (path-append hindi_data_dir "pauses/coef/")))


;;;;;;;;;; YOU CAN DEFINE THE VOICE SPECIFIC FUNCTIONS HERE  ;;;;;;;;;;;;; 


(set! hpl-hindi-backoff_rules
'(

(_ SIL)

))


(define (synth_file name)
  "(synth_file filename) 
Process and synthesize text in the file and also play the utterance."
  (let 
(
(utt1 (hpl_hin_tokenize (eval (list 'Utterance 'Text name)))))
(hpl_hin_normalize utt1)
(hpl_hin_g2p utt1)
(hpl_dummy_pos utt1) ; dummy pos
(Phrasify utt1)
(Wave_Synth utt1)
(utt.play utt1)
))



(define (synth_file_to_file name)
  "(synth_file_to_file filename) 
Process and synthesize text in the file and also write the utterance out to file."
  (let 
(
(utt1 (hpl_hin_tokenize (eval (list 'Utterance 'Text name)))))
(hpl_hin_normalize utt1)
(hpl_hin_g2p utt1)
(hpl_dummy_pos utt1) ; dummy pos
(Phrasify utt1)
(Wave_Synth utt1)
(save_tts_output utt1)
))



(make_voice_definition 'hpl_hindi_multisyn 
		       8000
		       'voice_hindi_multisyn_configure
                       hpl-hindi-backoff_rules
		       hindi_data_dir
		       (list (list hindi_base_dirs "utts.aci")
			     (list hindi_pauses_dirs "utts.pauses")))



(define (voice_hindi_multisyn_configure voice)
  "(voice_hindi_multisyn_configure voice)
 Set up the current voice to be male Hindi for
 the multisyn unitselection engine."
  (let (this_voice)
    (voice_reset)
    (Parameter.set 'Language 'Hindi)
    (set! hpl_hindi_phoneset (path-append hindi_data_dir1 "files_scm/hpl_hindi_phoneset.scm"))
    (load hpl_hindi_phoneset)
    (PhoneSet.select 'hpl_hindi) 
    (set! number_year_time_cart (path-append hindi_data_dir1 "files_scm/number_year_cart_tree.scm"))
    (load number_year_time_cart)
    (Parameter.set 'Phrase_Method 'cart_tree)
    (set! phrase_cart_tree simple_phrase_cart_tree)
    (Parameter.set 'Pause_Method MultiSyn_Pauses)
    (Parameter.set 'Int_Method nil)
    (Parameter.set 'Int_Target_Method nil)
    (set! hpl_hindi_dur_tree (path-append hindi_data_dir1 "files_scm/hpl_hindi_durtree.scm"))
    (load hpl_hindi_dur_tree)
    (set! duration_cart_tree hpl_hindi_duration_cart_tree)
    (set! duration_ph_info hpl_hindi_durs)
    (Parameter.set 'Duration_Method 'Tree_ZScores)
    (Param.set 'Synth_Method 'MultiSyn)
    (Param.set 'unisyn.window_symmetric 0)))


(proclaim_voice
 'hpl_hindi_multisyn
 '((language Hindi)(gender male)(dialect Indian)
   (description "Hewlett-Packard Labs India Hindi multisyn (default configuration).")))


(provide 'hpl_hindi_multisyn)

